@@ -6,6 +6,7 @@ from fastapi import APIRouter, Depends
 from fastapi.responses import HTMLResponse
 from fastapi.staticfiles import StaticFiles
 from fps.hooks import register_router  # type: ignore
+from fps_frontend.config import get_frontend_config  # type: ignore
 from fps_lab.config import get_lab_config  # type: ignore
 from fps_lab.routes import init_router  # type: ignore
 from fps_lab.utils import get_federated_extensions  # type: ignore
@@ -44,45 +45,50 @@ retro_federated_extensions = [
 @router.get("/retro/tree", response_class=HTMLResponse)
 async def get_tree(
     user: User = Depends(current_user()),
+    frontend_config=Depends(get_frontend_config),
     lab_config=Depends(get_lab_config),
 ):
-    return get_index("Tree", "tree", lab_config.collaborative, lab_config.base_url)
+    return get_index("Tree", "tree", lab_config.collaborative, frontend_config.base_url)
 
 
 @router.get("/retro/notebooks/{path:path}", response_class=HTMLResponse)
 async def get_notebook(
     path,
     user: User = Depends(current_user()),
+    frontend_config=Depends(get_frontend_config),
     lab_config=Depends(get_lab_config),
 ):
-    return get_index(path, "notebooks", lab_config.collaborative, lab_config.base_url)
+    return get_index(path, "notebooks", lab_config.collaborative, frontend_config.base_url)
 
 
 @router.get("/retro/edit/{path:path}", response_class=HTMLResponse)
 async def edit_file(
     path,
     user: User = Depends(current_user()),
+    frontend_config=Depends(get_frontend_config),
     lab_config=Depends(get_lab_config),
 ):
-    return get_index(path, "edit", lab_config.collaborative, lab_config.base_url)
+    return get_index(path, "edit", lab_config.collaborative, frontend_config.base_url)
 
 
 @router.get("/retro/consoles/{path:path}", response_class=HTMLResponse)
 async def get_console(
     path,
     user: User = Depends(current_user()),
+    frontend_config=Depends(get_frontend_config),
     lab_config=Depends(get_lab_config),
 ):
-    return get_index(path, "consoles", lab_config.collaborative, lab_config.base_url)
+    return get_index(path, "consoles", lab_config.collaborative, frontend_config.base_url)
 
 
 @router.get("/retro/terminals/{name}", response_class=HTMLResponse)
 async def get_terminal(
     name: str,
     user: User = Depends(current_user()),
+    frontend_config=Depends(get_frontend_config),
     lab_config=Depends(get_lab_config),
 ):
-    return get_index(name, "terminals", lab_config.collaborative, lab_config.base_url)
+    return get_index(name, "terminals", lab_config.collaborative, frontend_config.base_url)
 
 
 def get_index(doc_name, retro_page, collaborative, base_url="/"):
